@@ -194,6 +194,7 @@ namespace gnote {
   NoteWindow::~NoteWindow()
   {
     delete m_global_keys;
+    delete m_mark_set_timeout;
     Preferences::obj().remove_notify(m_gconf_notify);
   }
 
@@ -421,9 +422,9 @@ namespace gnote {
     tb->insert(*m_link_button, -1);
 
     utils::ToolMenuButton *text_button = manage(new utils::ToolMenuButton(*tb,
-                                                            Gtk::Stock::SELECT_FONT,
-                                                            _("_Text"),
-                                                            *m_text_menu));
+                                                  Gtk::Stock::SELECT_FONT,
+                                                  _("_Text"),
+                                                  m_text_menu));
     text_button->set_use_underline(true);
     text_button->set_is_important(true);
     text_button->show_all();
@@ -431,10 +432,9 @@ namespace gnote {
     text_button->set_tooltip_text(_("Set properties of text"));
 
     utils::ToolMenuButton *plugin_button = Gtk::manage(
-      new utils::ToolMenuButton (*tb,
-                          Gtk::Stock::EXECUTE,
-                          _("T_ools"),
-                          *m_plugin_menu));
+      new utils::ToolMenuButton (*tb, Gtk::Stock::EXECUTE,
+                                 _("T_ools"),
+                                 m_plugin_menu));
     plugin_button->set_use_underline(true);
     plugin_button->show_all();
     tb->insert(*plugin_button, -1);
@@ -596,7 +596,7 @@ namespace gnote {
 
   void NoteWindow::open_help_activate()
   {
-    utils::show_help("gnote.xml", "editing-notes", get_screen()->gobj(), this);
+    utils::show_help("gnote", "editing-notes", get_screen()->gobj(), this);
   }
 
   void NoteWindow::create_new_note ()
