@@ -293,7 +293,7 @@ namespace gnote {
     m_on_notebook_selection_changed_cid = m_notebooksTree->get_selection()->signal_changed()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebook_selection_changed));
     m_notebooksTree->signal_button_press_event()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebooks_tree_button_pressed));
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebooks_tree_button_pressed), false);
     m_notebooksTree->signal_key_press_event()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notebooks_key_pressed));
       
@@ -330,9 +330,9 @@ namespace gnote {
     m_tree->get_selection()->signal_changed().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_selection_changed));
     m_tree->signal_button_press_event().connect(
-      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_pressed));
+      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_pressed), false);
     m_tree->signal_motion_notify_event().connect(
-      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_motion_notify));
+      sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_motion_notify), false);
     m_tree->signal_button_release_event().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_released));
     m_tree->signal_drag_data_get().connect(
@@ -576,17 +576,29 @@ namespace gnote {
 
   void NoteRecentChanges::update_total_note_count (int total)
   {
-    const char * fmt;
-    fmt = ngettext("Total: %1% note", "Total: %1% notes", total);
-    m_note_count.set_text(str(boost::format (fmt) % total));
+    try {
+      const char * fmt;
+      fmt = ngettext("Total: %1% note", "Total: %1% notes", total);
+      m_note_count.set_text(str(boost::format (fmt) % total));
+    } 
+    catch(const std::exception & e)
+    {
+      ERR_OUT("exception: %s", e.what());
+    }
   }
                 
   
   void NoteRecentChanges::update_match_note_count (int matches)
   {
-    const char * fmt;
-    fmt = ngettext("Matches: %1% note", "Matches: %1% notes", matches);
-    m_note_count.set_text(str(boost::format (fmt) % matches));
+    try {
+      const char * fmt;
+      fmt = ngettext("Matches: %1% note", "Matches: %1% notes", matches);
+      m_note_count.set_text(str(boost::format (fmt) % matches));
+    }
+    catch(const std::exception & e)
+    {
+      ERR_OUT("exception: %s", e.what());
+    }
   }
                 
 
@@ -1332,7 +1344,7 @@ namespace gnote {
   void NoteRecentChanges::on_delete_notebook()
   {
     notebooks::Notebook::Ptr notebook = get_selected_notebook ();
-    if (notebook)
+    if (!notebook)
       return;
       
     notebooks::NotebookManager::prompt_delete_notebook (this, notebook);
