@@ -45,11 +45,9 @@
 
 namespace gnote {
 
-  namespace {
-
   std::string tray_util_get_tooltip_text()
   {
-    std::string tip_text = _("GNote Notes");
+    std::string tip_text = _("Gnote Notes");
     
     if (Preferences::obj().get<bool>(Preferences::ENABLE_KEYBINDINGS)) {
       std::string shortcut =
@@ -62,7 +60,6 @@ namespace gnote {
     return tip_text;
   }
 
-  }
 
 
   bool                      NoteMenuItem::s_static_inited = false;
@@ -412,7 +409,8 @@ namespace gnote {
     Glib::RefPtr<Gdk::Pixbuf> pixbuf = utils::get_icon("gnote", panel_size);
     set(pixbuf);
 #if GTK_VERSION_GE(2,16)
-    set_tooltip_text(tray_util_get_tooltip_text());
+    gtk_status_icon_set_tooltip_text(gobj(), 
+                                     tray_util_get_tooltip_text().c_str());
 #endif
 
     Gtk::Main::signal_quit().connect(sigc::mem_fun(*this, &TrayIcon::on_exit), 1);
@@ -509,7 +507,7 @@ namespace gnote {
     item->signal_activate().connect(sigc::mem_fun(*this, &TrayIcon::show_help_contents));
     m_context_menu->append(*item);
 
-    item = manage(new Gtk::ImageMenuItem(_("_About GNote"), true));
+    item = manage(new Gtk::ImageMenuItem(_("_About Gnote"), true));
     item->set_image(*manage(new Gtk::Image(Gtk::Stock::ABOUT, Gtk::ICON_SIZE_MENU)));
     item->signal_activate().connect(sigc::mem_fun(*this, &TrayIcon::show_about));
     m_context_menu->append(*item);
